# TinUI

![](https://github.com/Smart-Space/TinUI/raw/main/image/LOGO.png)

---

## 项目简介

TinUI是一个基于tkinter的拓展组件（Widget），可以绘制具有现代化样式的控件。

详细介绍见[TinUI · 轻量的tkinter现代样式控件](https://tinui.smart-space.com.cn/)。

## 安装

使用pip：

```cmd
pip install tinui
```

---
部分展示：

<img src="https://github.com/Smart-Space/TinUI/raw/main/image/themes1.png" width="400" />

<img src="https://github.com/Smart-Space/TinUI/raw/main/image/themes2.png" width="400" />

<img src="https://github.com/Smart-Space/TinUI/raw/main/image/themes3.png" width="400" />

<img src="https://github.com/Smart-Space/TinUI/raw/main/image/themes4.png" width="400" />

<img src="https://github.com/Smart-Space/TinUI/raw/main/image/themes5.png" width="400" />